summaryrefslogtreecommitdiffstats
path: root/lib/kofficeui/KoPageLayoutSize.h
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-16 09:56:31 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-16 09:56:31 -0600
commitc9cb4f487428aad5d8cda5e3a4b9ad87390d7e54 (patch)
tree1ee1912ac4bb966475f0db0f2a78678661b4b4a5 /lib/kofficeui/KoPageLayoutSize.h
parent94844816550ad672ccfcdc25659c625546239998 (diff)
downloadkoffice-c9cb4f487428aad5d8cda5e3a4b9ad87390d7e54.tar.gz
koffice-c9cb4f487428aad5d8cda5e3a4b9ad87390d7e54.zip
Revert "Rename a number of old tq methods that are no longer tq specific"
This reverts commit 94844816550ad672ccfcdc25659c625546239998.
Diffstat (limited to 'lib/kofficeui/KoPageLayoutSize.h')
-rw-r--r--lib/kofficeui/KoPageLayoutSize.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/lib/kofficeui/KoPageLayoutSize.h b/lib/kofficeui/KoPageLayoutSize.h
index 6d50e014..d917b349 100644
--- a/lib/kofficeui/KoPageLayoutSize.h
+++ b/lib/kofficeui/KoPageLayoutSize.h
@@ -42,13 +42,13 @@ public:
/**
* Contructor
* @param parent the parent widget
* @param layout the page layout that this widget should be initialzed with.
* @param unit the unit-type (mm/cm/inch) that the dialog should show
* @param columns the KoColumns (amout of columns) that the preview should be initialized with
* @param unitChooser if true a combobox with the unit-type is shown for the user to change
* @param enableBorders if true enable the user to change the margins (aka borders) of the page
*/
- KoPageLayoutSize(TQWidget *parent, const KoPageLayout& layout, KoUnit::Unit unit,
+ KoPageLayoutSize(TQWidget *parent, const KoPageLayout& tqlayout, KoUnit::Unit unit,
const KoColumns& columns, bool unitChooser, bool enableBorders);
/**
@@ -78,11 +78,11 @@ public slots:
signals:
/**
* Emitted whenever the user changed something in the dialog.
* @param layout the update layout structure with currently displayed info.
* Note that the info may not be fully correct and physically possible (in which
* case queryClose will return false)
*/
- void propertyChange(KoPageLayout &layout);
+ void propertyChange(KoPageLayout &tqlayout);
protected:
TQComboBox *cpgFormat;
@@ -42,13 +42,13 @@ public:
* Contructor
* @param parent the parent widget
- * @param layout the page layout that this widget should be initialzed with.
+ * @param tqlayout the page tqlayout that this widget should be initialzed with.
* @param unit the unit-type (mm/cm/inch) that the dialog should show
* @param columns the KoColumns (amout of columns) that the preview should be initialized with
@@ -78,11 +78,11 @@ public slots:
/**
* Emitted whenever the user changed something in the dialog.
- * @param layout the update layout structure with currently displayed info.
+ * @param tqlayout the update tqlayout structure with currently displayed info.
* Note that the info may not be fully correct and physically possible (in which
* case queryClose will return false)